@@ -3,7 +3,6 @@ from __future__ import absolute_import
 import typing
 
 from oslo_log import log
-import pandas
 
 import tobiko
 from tobiko.tripleo import overcloud
@@ -34,7 +33,7 @@ cloud-final.service|loaded|active|exited|Executeclouduser/finalscripts
 cloud-init-local.service|loaded|active|exited|Initialcloud-initjob(pre-network)
 cloud-init.service|loaded|active|exited|Initialcloud-initjob(metadataservicecr)
 
-    :return: dataframe of overcloud node services
+    :return: TableData of overcloud node services
     """
     units = sh.list_systemd_units(all=True,
                                   ssh_client=ssh_client).without_attributes(
@@ -51,9 +50,12 @@ cloud-init.service|loaded|active|exited|Initialcloud-initjob(metadataservicecr)
         data['active_state'].append(unit.active)
         data['low_level_state'].append(unit.sub)
         data['UNIT_DESCRIPTION'].append(unit.description)
-    table = pandas.DataFrame.from_dict(data)
+    table = tobiko.TableData.from_dict(data)
     table.replace(to_replace=' ', value="", regex=True, inplace=True)
-    table['overcloud_node'] = sh.get_hostname(ssh_client=ssh_client)
+    # Add hostname to each row
+    hostname = sh.get_hostname(ssh_client=ssh_client)
+    for row in table:
+        row['overcloud_node'] = hostname
 
     LOG.debug("Got overcloud nodes services status :\n%s", table)
     return table
@@ -65,15 +67,15 @@ def get_overcloud_nodes_running_service(service):
     process: exact str of a process name as seen in systemctl -a
     :return: list of overcloud nodes
     """
-    oc_procs_df = overcloud.get_overcloud_nodes_dataframe(
+    oc_procs_td = overcloud.get_overcloud_nodes_tabledata(
                                             get_overcloud_node_services_table)
     # remove the ".service" suffix
-    oc_procs_df = oc_procs_df.replace(to_replace={'UNIT': '.service'},
-                                      value='',
-                                      regex=True)
-    oc_nodes_running_service = oc_procs_df.query('UNIT=="{}"'.format(service))[
-                                                'overcloud_node'].unique()
-    return oc_nodes_running_service.tolist()
+    oc_procs_td.replace(to_replace={'UNIT': '.service'},
+                        value='',
+                        regex=True, inplace=True)
+    oc_nodes_running_service = oc_procs_td.query(
+        'UNIT=="{}"'.format(service))['overcloud_node'].unique()
+    return oc_nodes_running_service
 
 
 class OvercloudServicesStatus(tobiko.SharedFixture):
@@ -102,22 +104,22 @@ class OvercloudServicesStatus(tobiko.SharedFixture):
             services_to_check = self.SERVICES_TO_CHECK
         self.services_to_check = services_to_check
 
-    oc_services_df: typing.Any
+    oc_services_td: typing.Any
 
     def setup_fixture(self):
-        self.oc_services_df = overcloud.get_overcloud_nodes_dataframe(
+        self.oc_services_td = overcloud.get_overcloud_nodes_tabledata(
             get_overcloud_node_services_table)
 
     @property
     def basic_overcloud_services_running(self):
         """
-        Checks that the oc_services dataframe has all of the list services
+        Checks that the oc_services tabledata has all of the list services
         running
         :return: Bool
         """
         tobiko.setup_fixture(self)
         for service_name in self.services_to_check:
-            if not self.oc_services_df.query('UNIT=="{}"'.format(
+            if not self.oc_services_td.query('UNIT=="{}"'.format(
                     service_name)).empty:
                 LOG.info("overcloud processes status checks: process {} is  "
                          "in running state".format(service_name))
